//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-pdf-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Annotations;
using System.Collections.Generic;
using GrapeCity.Documents.Common;

namespace DsPdfWeb.Demos
{
    // This example shows how to find all occurrences of two words in a PDF document and
    // underline those occurrences using the text markup underline annotation.
    public class FindAndUnderline
    {
        public int CreatePDF(Stream stream)
        {
            // Load the PDF:
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "The-Rich-History-of-JavaScript.pdf"));
            doc.Load(fs);

            // Find all occurrences of "JavaScript" or "ECMAScript" using regex:
            var ft = new FindTextParams("JavaScript|ECMAScript", wholeWord: false, matchCase: false, regex: true);
            var found = doc.FindText(ft, null);

            // Add a text markup annotation to underline each occurrence:
            foreach (var f in found)
            {
                var markup = new TextMarkupAnnotation()
                {
                    Page = doc.Pages[f.PageIndex],
                    MarkupType = TextMarkupType.Underline,
                    Color = Color.Red
                };
                List<Quadrilateral> area = new List<Quadrilateral>();
                foreach (var b in f.Bounds)
                    area.Add(b);
                markup.Area = area;
            }

            // Done:
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
